@@ -1,7 +1,7 @@
-from .split import ratio, fixed
-
 import argparse
 
+from .split import fixed, ratio
+
 
 def run():
     parser = argparse.ArgumentParser(
@@ -28,7 +28,7 @@ def run():
         "--fixed",
         nargs="+",
         type=int,
-        help="set the absolute number of items per validation/test set. The remaining items get to the training. e.g. for train/val/test `100 100` or for train/val `100`",
+        help="set the absolute number of items per validation/test set. The remaining items get to the training. e.g. for train/val/test `100 100` or for train/val `100`. Set 3 values, e.g. `300 100 100`, to limit the number of training values.",
     )
     parser.add_argument(
         "--oversample",
@@ -41,6 +41,11 @@ def run():
         default=None,
         help="split files into equally-sized groups based on their prefix",
     )
+    parser.add_argument(
+        "--move",
+        action="store_true",
+        help="move the files instead of copying",
+    )
     parser.add_argument(
         "input",
         help="directory with the input data. The directory needs to have the labels as sub-directories. In those sub-directories are then the actual files that gets split.",
@@ -49,10 +54,20 @@ def run():
     args = parser.parse_args()
 
     if args.ratio:
-        ratio(args.input, args.output, args.seed, args.ratio)
+        ratio(
+            args.input, args.output, args.seed, args.ratio, args.group_prefix, args.move
+        )
     else:
         if args.fixed:
-            fixed(args.input, args.output, args.seed, args.fixed, args.oversample)
+            fixed(
+                args.input,
+                args.output,
+                args.seed,
+                args.fixed,
+                args.oversample,
+                args.group_prefix,
+                args.move,
+            )
         else:
             print(
                 "Please specify either your `--ratio` or your `--fixed` number of items for the split. see -h for more help."
